@@ -1,6 +1,6 @@
 /*
 goredo -- djb's redo implementation on pure Go
-Copyright (C) 2020-2021 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2020-2022 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@ const (
 	CmdNameRedoStamp    = "redo-stamp"
 	CmdNameRedoTargets  = "redo-targets"
 	CmdNameRedoWhichdo  = "redo-whichdo"
+	CmdNameRedoDepFix   = "redo-depfix"
 )
 
 var (
@@ -112,6 +113,7 @@ func main() {
 			CmdNameRedoAffects,
 			CmdNameRedoAlways,
 			CmdNameRedoCleanup,
+			CmdNameRedoDepFix,
 			CmdNameRedoDot,
 			CmdNameRedoIfchange,
 			CmdNameRedoIfcreate,
@@ -196,6 +198,7 @@ func main() {
 	}
 	NoColor = os.Getenv(EnvNoColor) != ""
 	NoSync = os.Getenv(EnvNoSync) == "1"
+	StopIfMod = os.Getenv(EnvStopIfMod) == "1"
 	switch s := os.Getenv(EnvInodeTrust); s {
 	case "none":
 		InodeTrust = InodeTrustNone
@@ -227,7 +230,11 @@ func main() {
 	if v := os.Getenv(EnvOODTgtsFd); v != "" {
 		fd := mustParseFd(v, EnvOODTgtsFd)
 		fdLock := mustParseFd(v, EnvOODTgtsLockFd)
-		if err = unix.Flock(int(fdLock.Fd()), unix.LOCK_EX); err != nil {
+		flock := unix.Flock_t{
+			Type:   unix.F_WRLCK,
+			Whence: io.SeekStart,
+		}
+		if err = unix.FcntlFlock(fdLock.Fd(), unix.F_SETLKW, &flock); err != nil {
 			log.Fatalln(err)
 		}
 		if _, err = fd.Seek(0, io.SeekStart); err != nil {
@@ -237,7 +244,8 @@ func main() {
 		if err != nil {
 			log.Fatalln(err)
 		}
-		if err = unix.Flock(int(fdLock.Fd()), unix.LOCK_UN); err != nil {
+		flock.Type = unix.F_UNLCK
+		if err = unix.FcntlFlock(fdLock.Fd(), unix.F_SETLK, &flock); err != nil {
 			log.Fatalln(err)
 		}
 		OODTgts = map[string]struct{}{}
@@ -337,8 +345,8 @@ CmdSwitch:
 		}
 		for _, tgt := range tgts {
 			tgtRel, err := filepath.Rel(
-				filepath.Join(Cwd, DirPrefix),
-				filepath.Join(Cwd, tgt),
+				path.Join(Cwd, DirPrefix),
+				path.Join(Cwd, tgt),
 			)
 			if err != nil {
 				break
@@ -489,6 +497,8 @@ CmdSwitch:
 		for _, src := range srcs {
 			fmt.Println(src)
 		}
+	case CmdNameRedoDepFix:
+		err = depFix(Cwd)
 	default:
 		log.Fatalln("unknown command", cmdName)
 	}
