@@ -1,6 +1,6 @@
 /*
 goredo -- djb's redo implementation on pure Go
-Copyright (C) 2020-2021 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2020-2022 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -51,6 +51,7 @@ const (
 	EnvStderrKeep   = "REDO_LOGS"
 	EnvStderrSilent = "REDO_SILENT"
 	EnvNoSync       = "REDO_NO_SYNC"
+	EnvStopIfMod    = "REDO_STOP_IF_MODIFIED"
 
 	RedoDir      = ".redo"
 	LockSuffix   = ".lock"
@@ -65,6 +66,7 @@ var (
 	StderrKeep   = false
 	StderrSilent = false
 	StderrPrefix string
+	StopIfMod    = false
 	Jobs         sync.WaitGroup
 
 	flagTrace        *bool
@@ -198,9 +200,14 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 	if err != nil {
 		return TgtError{tgtOrig, err}
 	}
+	flock := unix.Flock_t{
+		Type:   unix.F_WRLCK,
+		Whence: io.SeekStart,
+	}
 	lockRelease := func() {
 		tracef(CLock, "LOCK_UN: %s", fdLock.Name())
-		if err := unix.Flock(int(fdLock.Fd()), unix.LOCK_UN); err != nil {
+		flock.Type = unix.F_UNLCK
+		if err := unix.FcntlFlock(fdLock.Fd(), unix.F_SETLK, &flock); err != nil {
 			log.Fatalln(err)
 		}
 		fdLock.Close()
@@ -208,13 +215,16 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 	tracef(CLock, "LOCK_NB: %s", fdLock.Name())
 
 	// Waiting for job completion, already taken by someone else
-	if err = unix.Flock(int(fdLock.Fd()), unix.LOCK_EX|unix.LOCK_NB); err != nil {
-		if uintptr(err.(syscall.Errno)) != uintptr(unix.EWOULDBLOCK) {
+	if err = unix.FcntlFlock(fdLock.Fd(), unix.F_SETLK, &flock); err != nil {
+		if uintptr(err.(syscall.Errno)) != uintptr(unix.EAGAIN) {
 			fdLock.Close()
 			return TgtError{tgtOrig, err}
 		}
 		Jobs.Add(1)
-		tracef(CDebug, "waiting: %s", tgtOrig)
+		if err = unix.FcntlFlock(fdLock.Fd(), unix.F_GETLK, &flock); err != nil {
+			log.Fatalln(err)
+		}
+		tracef(CDebug, "waiting: %s (pid=%d)", tgtOrig, flock.Pid)
 		if FdStatus != nil {
 			if _, err = FdStatus.Write([]byte{StatusWait}); err != nil {
 				log.Fatalln(err)
@@ -223,7 +233,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		go func() {
 			defer Jobs.Done()
 			tracef(CLock, "LOCK_EX: %s", fdLock.Name())
-			if err := unix.Flock(int(fdLock.Fd()), unix.LOCK_EX); err != nil {
+			if err := unix.FcntlFlock(fdLock.Fd(), unix.F_SETLKW, &flock); err != nil {
 				log.Fatalln(err)
 			}
 			lockRelease()
@@ -265,8 +275,11 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		return TgtError{tgtOrig, err}
 	}
 	if modified {
-		tracef(CWarn, "%s externally modified: not redoing", tgtOrig)
 		lockRelease()
+		if StopIfMod {
+			return fmt.Errorf("%s externally modified", tgtOrig)
+		}
+		tracef(CWarn, "%s externally modified: not redoing", tgtOrig)
 		go func() {
 			errs <- nil
 		}()
