@@ -1,6 +1,6 @@
 /*
 goredo -- djb's redo implementation on pure Go
-Copyright (C) 2020-2021 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2020-2022 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@ import (
 )
 
 const (
-	Version  = "1.21.0"
-	Warranty = `Copyright (C) 2020-2021 Sergey Matveev
+	Version  = "1.22.0"
+	Warranty = `Copyright (C) 2020-2022 Sergey Matveev
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -105,13 +105,18 @@ List all currently known out-of-date targets.`
 		d = `Usage: redo-affects target [...]
 
 List all targets that will be affected by changing the specified ones.`
+	case CmdNameRedoDepFix:
+		d = `Usage: redo-depfix
+
+Traverse over all .redo directories beneath and check if inode's information
+(ctime/mtime) differs. Update dependency if file's content is still the same.`
 	default:
 		d = `Usage: goredo -symlinks
 
 goredo expects to be called through the symbolic link to it.
 Available commands: redo, redo-affects, redo-always, redo-cleanup,
-redo-dot, redo-ifchange, redo-ifcreate, redo-log, redo-ood,
-redo-sources, redo-stamp, redo-targets, redo-whichdo.`
+redo-depfix, redo-dot, redo-ifchange, redo-ifcreate, redo-log,
+redo-ood, redo-sources, redo-stamp, redo-targets, redo-whichdo.`
 	}
 	fmt.Fprintf(os.Stderr, "%s\n\nCommon options:\n", d)
 	flag.PrintDefaults()
